api.assets.v1.test_helpers.application package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.application package

## Submodules

## api.assets.v1.test_helpers.application.add_host_application module

`api.assets.v1.test_helpers.application.add_host_application.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 403

`api.assets.v1.test_helpers.application.add_host_application.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 404

`api.assets.v1.test_helpers.application.add_host_application.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 200

`api.assets.v1.test_helpers.application.add_host_application.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 401

## api.assets.v1.test_helpers.application.delete_host_application module

`api.assets.v1.test_helpers.application.delete_host_application.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 403

`api.assets.v1.test_helpers.application.delete_host_application.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 404

`api.assets.v1.test_helpers.application.delete_host_application.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 200

`api.assets.v1.test_helpers.application.delete_host_application.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 401

## api.assets.v1.test_helpers.application.get_host_application module

`api.assets.v1.test_helpers.application.get_host_application.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 403

`api.assets.v1.test_helpers.application.get_host_application.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 404

`api.assets.v1.test_helpers.application.get_host_application.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 200

`api.assets.v1.test_helpers.application.get_host_application.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 401

## api.assets.v1.test_helpers.application.search_host_applications module

`api.assets.v1.test_helpers.application.search_host_applications.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/search, respond with HTTP 403

`api.assets.v1.test_helpers.application.search_host_applications.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/search, respond with HTTP 404

`api.assets.v1.test_helpers.application.search_host_applications.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/search, respond with HTTP 200

`api.assets.v1.test_helpers.application.search_host_applications.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/search, respond with HTTP 401

## api.assets.v1.test_helpers.application.search_host_applications_simplified module

`api.assets.v1.test_helpers.application.search_host_applications_simplified.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 403

`api.assets.v1.test_helpers.application.search_host_applications_simplified.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 404

`api.assets.v1.test_helpers.application.search_host_applications_simplified.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 200

`api.assets.v1.test_helpers.application.search_host_applications_simplified.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application, respond with HTTP 401

## api.assets.v1.test_helpers.application.update_host_application module

`api.assets.v1.test_helpers.application.update_host_application.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 403

`api.assets.v1.test_helpers.application.update_host_application.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 404

`api.assets.v1.test_helpers.application.update_host_application.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 200

`api.assets.v1.test_helpers.application.update_host_application.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/assets/v1/application/w+, respond with HTTP 401

## Module contents